<?php
class WPBForWPbakeryPro_Cart_Table{
    function __construct() {
        // creating shortcode addon
        add_shortcode( 'wpbforwpbakery_cart_table', array( $this, 'render_shortcode' ) );

        // We safely integrate with VC with this hook
        add_action( 'vc_after_init', array( $this, 'integrateWithVC' ) );
    }

    public function render_shortcode( $atts, $content = null ) {
    	if( !is_cart() ){ 
    		return;
    	}
    	
        extract(shortcode_atts(array(
            'heading_text_align' => '', 
            'heading_text_color' => '', 
            'heading_font_size' => '',
            'use_heading_google_font' => '', 
            'heading_google_font' => 'font_family:Abril Fatface|font_style:400 regular',
            'table_cell_border_color'=>'',
            'el_class' => '', 
            'wrapper_css' => ''
        ),$atts));

        $unique_class = uniqid('wpbforwpbakery_cart_');

        $heading_fonts_style = '';
        if( $use_heading_google_font == 'true'){
            $heading_font_data = wpbforwpbakerypro_get_fonts_data( $heading_google_font );
            wpbforwpbakerypro_enqueue_google_font( $heading_font_data );
            $heading_fonts_style = wpbforwpbakerypro_get_font_inline_style( $heading_font_data );
        }

        $style = '<style>';

        if( $heading_text_align != "" ){
            $style .=  ".$unique_class .shop_table.cart th{ text-align:{$heading_text_align} !important; }";
        }

        if( $heading_text_color != "" ){
            $style .=  ".$unique_class .shop_table.cart th{ color:{$heading_text_color} !important; }";
        }

        if( $heading_font_size != "" ){
            $style .=  ".$unique_class .shop_table.cart th{ font-size:{$heading_font_size} !important; }";
        }

        if( $heading_fonts_style != "" ){
            $style .=  ".$unique_class .shop_table.cart th{ {$heading_fonts_style} }";
        }

        if( $table_cell_border_color != "" ){
            $style .=  ".$unique_class .shop_table.cart tr.cart_item td,.$unique_class .shop_table.cart{ border-color:{$table_cell_border_color} !important; }";
        }
        $style .= '</style>';

        ob_start();

        echo '<div class="'. esc_attr($unique_class. ' ' .$el_class) . esc_attr(wpbforwpbakerypro_get_vc_custom_class($wrapper_css, ' ')) .'">';
        echo WPBForWPbakeryPro_Cart_Shortcode::output( $atts );
        echo '</div>';

        return $style .= ob_get_clean();
    }

    public function integrateWithVC() {
        /*
        Lets call vc_map function to "register" our custom shortcode within WPBakery Page Builder interface.

        More info: http://kb.wpbakery.com/index.php?title=Vc_map
        */
        vc_map( array(
            "name" => esc_html__("WCB: Cart Table", 'wpbforwpbakerypro'),
            "base" => "wpbforwpbakery_cart_table",
            "class" => "",
            "controls" => "full",
            "icon" => 'wpbforwpbakerypro_cart_table_icon', // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => esc_html__('WC Builder', 'wpbforwpbakerypro'),
            "params" => array(
                array(
                  "param_name" => "heading_text_align",
                  "heading" => __("Heading Text Align", 'wpbforwpbakery'),
                  "type" => "dropdown",
                  "default_set" => 'left',
                  'value' => wpbforwpbakerypro_text_align_lists(),
                ),
                array(
                    'param_name' => 'heading_text_color',
                    'heading' => __( 'Heading Text color', 'wpbforwpbakery' ),
                    'type' => 'colorpicker',
                ),
                array(
                    'param_name' => 'heading_font_size',
                    'heading' => __( 'Heading Font Size', 'wpbforwpbakery' ),
                    'type' => 'textfield',
                    'description' => __( 'Ex: 23px', 'wpbforwpbakery' ),
                ),
                array(
                  'type' => 'checkbox',
                  'heading' => __( 'Use Heading google font?', 'wpbforwpbakery' ),
                  'param_name' => 'use_heading_google_font',
                  'description' => __( 'Use font family from google font.', 'wpbforwpbakery' ),
                ),
                array(
                  'type' => 'google_fonts',
                  'param_name' => 'heading_google_font',
                  'settings' => array(
                    'fields' => array(
                      'font_family_description' => __( 'Select font family.', 'wpbforwpbakery' ),
                      'font_style_description' => __( 'Select font styling.', 'wpbforwpbakery' ),
                    ),
                  ),
                  'dependency' =>[
                      'element' => 'use_heading_google_font',
                      'value' => array( 'true' ),
                  ],
                ),
                array(
                    'param_name' => 'table_cell_border_color',
                    'heading' => __( 'Table Cell border color', 'wpbforwpbakery' ),
                    'type' => 'colorpicker',
                ),
                array(
                    'param_name' => 'el_class',
                    'heading' => esc_html__( 'Extra class name', 'wpbforwpbakerypro' ),
                    'type' => 'textfield',
                    'description' => esc_html__( 'Style this element differently - add a class name and refer to it in custom CSS.', 'wpbforwpbakerypro' ),
                ),
                array(
                  "param_name" => "wrapper_css",
                  "heading" => esc_html__( "Wrapper Styling", 'wpbforwpbakerypro' ),
                  "type" => "css_editor",
                  'group'  => esc_html__( 'Wrapper Styling', 'wpbforwpbakerypro' ),
              ),
            )
        ) );
    }
}

new WPBForWPbakeryPro_Cart_Table();

/**
 * Cart Shortcode
 * WPBForWPbakeryPro_Cart_Shortcode
 * Used on the cart page, the cart shortcode displays the cart contents and interface for coupon codes and other cart bits and pieces.
 *
 * @author 		WooThemes
 * @category 	Shortcodes
 * @package 	WooCommerce/Shortcodes/Cart
 * @version     2.3.0
 */
class WPBForWPbakeryPro_Cart_Shortcode extends WC_Shortcode_Cart{
	/**
	 * Output the cart shortcode.
	 */
	public static function output( $atts = '' ) {
		// Constants.
		wc_maybe_define_constant( 'WOOCOMMERCE_CART', true );

		$atts = shortcode_atts( array(), $atts, 'woocommerce_cart' );

		// Update Shipping
		if ( ! empty( $_POST['calc_shipping'] ) && wp_verify_nonce( $_POST['_wpnonce'], 'woocommerce-cart' ) ) {
			self::calculate_shipping();

			// Also calc totals before we check items so subtotals etc are up to date
			WC()->cart->calculate_totals();
		}

		// Check cart items are valid
		do_action( 'woocommerce_check_cart_items' );

		// Calc totals
		WC()->cart->calculate_totals();

		if ( WC()->cart->is_empty() ) {
		} else {
			wc_get_template( 'cart-table.php',  array('woo-templates' => 1), WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'woo-templates/', WPBFORWPBAKERY_PRO_ADDONS_PL_PATH . 'woo-templates/'  );
		}
	}
}