<?php

// don't load directly
if (!defined('ABSPATH')) die('-1');

if(!class_exists('WPBForWPbakery_Product_Title')){
	class WPBForWPbakery_Product_Title{
	    function __construct() {

	        // creating shortcode addon
	        add_shortcode( 'wpbforwpbakery_product_title', array( $this, 'render_shortcode' ) );

	        // We safely integrate with VC with this hook
	        add_action( 'vc_after_init', array( $this, 'integrateWithVC' ) );
	    }

	    public function render_shortcode( $atts, $content = null ) {

	        extract(shortcode_atts(array(
	            'tag' => 'h1', 
	            'text_align' => '', 
	            'text_color' => '', 
	            'font_size' => '', 
	            'line_height' => '', 
	            'use_google_font' => '', 
	            'google_font' => 'font_family:Abril Fatface|font_style:400 regular', 
	            'el_class' => '', 
	            'wrapper_css' => '', 
	        ),$atts));

	        $style = '';
	        $styles = array();

	        if( $text_align != "" ){
	        	$styles[] = 'text-align:'. $text_align .'';
	        }

	        if( $text_color != "" ){
	        	$styles[] = 'color:'. $text_color .'';
	        }

	        if( $font_size != "" ){
	        	$styles[] = 'font-size:'. $font_size .'';
	        }

	        if( $line_height != "" ){
	        	$styles[] = 'line-height:'. $line_height .'';
	        }

	        $font_inline_style = '';
	        if($use_google_font == 'true'){
	        	$font_data = wpbforwpbakerypro_get_fonts_data( $google_font );
	        	wpbforwpbakerypro_enqueue_google_font( $font_data );
	        	$font_inline_style = wpbforwpbakerypro_get_font_inline_style( $font_data );
	        }

	        // concate styles
	        if ( ! empty( $styles ) ) {
	        	$style = 'style="' . esc_attr( implode( ';', $styles ) . ';' . $font_inline_style ) . '"';
	        }

	        ob_start();

	        echo '<div class="'. esc_attr($el_class) .wpbforwpbakerypro_get_vc_custom_class($wrapper_css, ' ') .'">';
	        printf('<%1$s class="" %2$s>%3$s</%1$s>',
	        	$tag,
	        	$style,
	        	get_the_title()
	        );
	        echo '</div>';

	        return ob_get_clean();
	  }

	  
	  public function integrateWithVC() {
	  
	      /*
	      Lets call vc_map function to "register" our custom shortcode within WPBakery Page Builder interface.

	      More info: http://kb.wpbakery.com/index.php?title=Vc_map
	      */
	      vc_map( array(
	          "name" => __("WCB: Product title", 'wpbforwpbakery'),
	          "base" => "wpbforwpbakery_product_title",
	          "class" => "",
	          "controls" => "full",
	          "icon" => 'wpbforwpbakerypro_product_title_icon', // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
	          "category" => __('WC Builder', 'wpbforwpbakery'),
	          "params" => array(
	              array(
	                  "param_name" => "tag",
	                  "heading" => __("Title HTML Tag", 'wpbforwpbakery'),
	                  "type" => "dropdown",
	                  "default_set" => 'normal',
	                  'value' => wpbforwpbakerypro_html_tag_lists(),
	              ),
	              array(
	                "param_name" => "text_align",
	                "heading" => __("Text Align", 'wpbforwpbakery'),
	                "type" => "dropdown",
	                "default_set" => 'left',
	                'value' => wpbforwpbakerypro_text_align_lists(),
	                'edit_field_class' => 'vc_col-sm-6 vc_column',
	              ),
	              array(
	                  'param_name' => 'text_color',
	                  'heading' => __( 'Text color', 'wpbforwpbakery' ),
	                  'type' => 'colorpicker',
	                  'edit_field_class' => 'vc_col-sm-6 vc_column',
	              ),
	              array(
	                  'param_name' => 'font_size',
	                  'heading' => __( 'Font Size', 'wpbforwpbakery' ),
	                  'type' => 'textfield',
	                  'description' => __( 'Ex: 23px', 'wpbforwpbakery' ),
	                  'edit_field_class' => 'vc_col-sm-6 vc_column',
	              ),
	              array(
	                  'param_name' => 'line_height',
	                  'heading' => __( 'Line Height', 'wpbforwpbakery' ),
	                  'type' => 'textfield',
	                  'description' => __( 'Ex: 25px', 'wpbforwpbakery' ),
	                  'edit_field_class' => 'vc_col-sm-6 vc_column',
	              ),
	              array(
	                'type' => 'checkbox',
	                'heading' => __( 'Use google font?', 'wpbforwpbakery' ),
	                'param_name' => 'use_google_font',
	                'description' => __( 'Use font family from google font.', 'wpbforwpbakery' ),
	              ),
	              array(
	                'type' => 'google_fonts',
	                'param_name' => 'google_font',
	                'settings' => array(
	                  'fields' => array(
	                    'font_family_description' => __( 'Select font family.', 'wpbforwpbakery' ),
	                    'font_style_description' => __( 'Select font styling.', 'wpbforwpbakery' ),
	                  ),
	                ),
	                'dependency' =>[
	                    'element' => 'use_google_font',
	                    'value' => array( 'true' ),
	                ],
	              ),

	              array(
	                  'param_name' => 'el_class',
	                  'heading' => __( 'Extra class name', 'wpbforwpbakery' ),
	                  'type' => 'textfield',
	                  'description' => __( 'Style this element differently - add a class name and refer to it in custom CSS.', 'wpbforwpbakery' ),
	              ),
	              array(
	                "param_name" => "wrapper_css",
	                "heading" => __( "Wrapper Styling", "wpbforwpbakery" ),
	                "type" => "css_editor",
	                'group'  => __( 'Wrapper Styling', 'wpbforwpbakery' ),
	            ),
	          )
	      ) );
	  }

	}

	// Finally initialize code
	new WPBForWPbakery_Product_Title();
}