<?php
class WPBForWPbakeryPro_Thankyou_Order_Details{
    function __construct() {
        // creating shortcode addon
        add_shortcode( 'wpbforwpbakery_thankyou_order_details', array( $this, 'render_shortcode' ) );

        // We safely integrate with VC with this hook
        add_action( 'vc_after_init', array( $this, 'integrateWithVC' ) );
    }

    public function render_shortcode( $atts, $content = null ) {
        extract(shortcode_atts(array(
            'el_class' => esc_html__('Thank you. Your order has been received.', 'wpbforwpbakerypro'), 
            'wrapper_css' => '', 
        ),$atts));

        ob_start();

        $unique_class = uniqid('wpbforwpbakerypro_');
        $output = '';

        echo '<div class="'. esc_attr($el_class . ' ' . $unique_class) . esc_attr(wpbforwpbakerypro_get_vc_custom_class($wrapper_css, ' ')) .'">';
        ?>
        
        <?php
        global $wp;
        
        if( isset( $wp->query_vars['order-received'] ) ){
            $received_order_id = $wp->query_vars['order-received'];
        }else{
           $received_order_id = wpbforwpbakerypro_get_last_order_id();
        }

        if( !$received_order_id ){ return; }
        
        $order = wc_get_order( $received_order_id );
        $order_id = $order->get_id();
        
        
        if ( ! $order = wc_get_order( $order_id ) ) { return; }
        
        $order_items           = $order->get_items( apply_filters( 'woocommerce_purchase_order_item_types', 'line_item' ) );
        $show_purchase_note    = $order->has_status( apply_filters( 'woocommerce_purchase_note_order_statuses', array( 'completed', 'processing' ) ) );
        $show_customer_details = is_user_logged_in() && $order->get_user_id() === get_current_user_id();
        $downloads             = $order->get_downloadable_items();
        $show_downloads        = $order->has_downloadable_item() && $order->is_download_permitted();
        
        if ( $show_downloads ) {
            wc_get_template( 'order/order-downloads.php', array( 'downloads' => $downloads, 'show_title' => true ) );
        }
        ?>
        <section class="woocommerce-order-details">
            <?php do_action( 'woocommerce_order_details_before_order_table', $order ); ?>
        
            <h2 class="woocommerce-order-details__title"><?php esc_html_e( 'Order details', 'wpbforwpbakerypro' ); ?></h2>
        
            <table class="woocommerce-table woocommerce-table--order-details shop_table order_details">
        
                <thead>
                    <tr>
                        <th class="woocommerce-table__product-name product-name"><?php esc_html_e( 'Product', 'wpbforwpbakerypro' ); ?></th>
                        <th class="woocommerce-table__product-table product-total"><?php esc_html_e( 'Total', 'wpbforwpbakerypro' ); ?></th>
                    </tr>
                </thead>
        
                <tbody>
                    <?php
                    do_action( 'woocommerce_order_details_before_order_table_items', $order );
        
                    foreach ( $order_items as $item_id => $item ) {
                        $product = $item->get_product();
                        wc_get_template( 'order/order-details-item.php', array(
                            'order'              => $order,
                            'item_id'            => $item_id,
                            'item'               => $item,
                            'show_purchase_note' => $show_purchase_note,
                            'purchase_note'      => $product ? $product->get_purchase_note() : '',
                            'product'            => $product,
                        ) );
                    }
        
                    do_action( 'woocommerce_order_details_after_order_table_items', $order );
                    ?>
                </tbody>
        
                <tfoot>
                    <?php
                        foreach ( $order->get_order_item_totals() as $key => $total ) {
                            ?>
                            <tr>
                                <th scope="row"><?php echo esc_html($total['label']); ?></th>
                                <td><?php echo ( 'payment_method' === $key ) ? esc_html( $total['value'] ) : $total['value']; ?></td>
                            </tr>
                            <?php
                        }
                    ?>
                    <?php if ( $order->get_customer_note() ) : ?>
                        <tr>
                            <th><?php esc_html_e( 'Note:', 'wpbforwpbakerypro' ); ?></th>
                            <td><?php echo wptexturize( $order->get_customer_note() ); ?></td>
                        </tr>
                    <?php endif; ?>
                </tfoot>
            </table>
        
            <?php do_action( 'woocommerce_order_details_after_order_table', $order ); ?>
        </section>
        
        <?php
    	echo '</div>';
        return $output.= ob_get_clean();
    }

    public function integrateWithVC() {
        /*
        Lets call vc_map function to "register" our custom shortcode within WPBakery Page Builder interface.

        More info: http://kb.wpbakery.com/index.php?title=Vc_map
        */
        vc_map( array(
            "name" => esc_html__("WCB: Thank You Order Details", 'wpbforwpbakerypro'),
            "base" => "wpbforwpbakery_thankyou_order_details",
            "class" => "",
            "controls" => "full",
            "icon" => 'wpbforwpbakerypro_thankyou_order_details_icon', // or css class name which you can reffer in your css file later. Example: "vc_extend_my_class"
            "category" => esc_html__('WC Builder', 'wpbforwpbakerypro'),
            "params" => array(
                array(
                    'param_name' => 'el_class',
                    'heading' => esc_html__( 'Extra class name', 'wpbforwpbakerypro' ),
                    'type' => 'textfield',
                    'description' => esc_html__( 'Style this element differently - add a class name and refer to it in custom CSS.', 'wpbforwpbakerypro' ),
                ),
                array(
                  "param_name" => "wrapper_css",
                  "heading" => esc_html__( "Wrapper Styling", 'wpbforwpbakerypro' ),
                  "type" => "css_editor",
                  'group'  => esc_html__( 'Wrapper Styling', 'wpbforwpbakerypro' ),
              ),
            )
        ) );
    }
}

new WPBForWPbakeryPro_Thankyou_Order_Details();