<?php

// Exit if accessed directly
if( ! defined( 'ABSPATH' ) ) exit();

/*
 * HTML Tag list
 * return array
 */
function wpbforwpbakerypro_html_tag_lists() {
    $html_tag_list = [
        'h1'   => esc_html__( 'H1', 'wpbforwpbakerypro' ),
        'h2'   => esc_html__( 'H2', 'wpbforwpbakerypro' ),
        'h3'   => esc_html__( 'H3', 'wpbforwpbakerypro' ),
        'h4'   => esc_html__( 'H4', 'wpbforwpbakerypro' ),
        'h5'   => esc_html__( 'H5', 'wpbforwpbakerypro' ),
        'h6'   => esc_html__( 'H6', 'wpbforwpbakerypro' ),
        'p'    => esc_html__( 'p', 'wpbforwpbakerypro' ),
        'div'  => esc_html__( 'div', 'wpbforwpbakerypro' ),
        'span' => esc_html__( 'span', 'wpbforwpbakerypro' ),
    ];
    return $html_tag_list;
}

/*
 * Text align options
 * return array
 */
function wpbforwpbakerypro_text_align_lists(){
	$text_align_list = [
	      esc_html__( 'Left', 'wpbforwpbakerypro' )  =>  'left',
	      esc_html__( 'Center', 'wpbforwpbakerypro' )  =>  'center',
	      esc_html__( 'Right', 'wpbforwpbakerypro' )  =>  'right'
	  ];

	return $text_align_list;
}

/*
 * Post Type ids list
 * return array
 */
function wpbforwpbakerypro_post_list_arr( $post_type = 'post', $per_page = 100 ){
    $arr = array();
	$arr[] = esc_html__('Default', 'wpbforwpbakerypro');
    
    $postarg = array(
        'numberposts'=>$per_page,
        'post_type'=>$post_type
    );

    $post_list = get_posts( $postarg );
    foreach ( $post_list as $post ) {
       $arr[$post->ID] = $post->post_title;
    }

	return $arr;
}

/**
* Woocommerce Product last order id return
*/
function wpbforwpbakerypro_get_last_order_id(){
    global $wpdb;
    $statuses = array_keys(wc_get_order_statuses());
    $statuses = implode( "','", $statuses );

    // Getting last Order ID (max value)
    $results = $wpdb->get_col( "
        SELECT MAX(ID) FROM {$wpdb->prefix}posts
        WHERE post_type LIKE 'shop_order'
        AND post_status IN ('$statuses')" 
    );
    return reset($results);
}

/*
 * Plugins Options value
 * return on/off
 */
function wpbforwpbakerypro_get_option( $option, $section, $default = '', $empty_check = false ){
    $options = get_option( $section );
    if ( isset( $options[$option] ) ) {

        if($empty_check){

            if( !empty($options[$option]) ){
                return $options[$option];
            }

            return $default;

        } else {
            return $options[$option];
        }
        
    }
    return $default;
}

/*
 * WPbakery Google Fonts
 * return array
 */
function wpbforwpbakerypro_get_fonts_data( $font_data ) {
	$FontsParam = new Vc_Google_Fonts();
	$fieldSettings = array();
	$font_data = strlen( $font_data ) > 0 ? $FontsParam->_vc_google_fonts_parse_attributes( $fieldSettings, $font_data ) : '';
	return $font_data;
}

/*
 * Generate Inline Style for google font
 * inline style
 */
function wpbforwpbakerypro_get_font_inline_style($font_data){
	$styles = array();

	// Inline styles
	$font_family = explode( ':', $font_data['values']['font_family'] );
	if( isset($font_family[0]) ){
		$styles[] = 'font-family:' . $font_family[0];
	}

	$fontStyles = explode( ':', $font_data['values']['font_style'] );
	if( isset($fontStyles[1]) ){
		$styles[] = 'font-weight:' . $fontStyles[1];
	}

	if( isset($fontStyles[2]) ){
		$styles[] = 'font-style:' . $fontStyles[2];
	}
	 
	$inline_style = '';
	foreach( $styles as $attribute ){
		$inline_style .= $attribute.'; ';
	}
	return $inline_style;
}

/*
 * enqueue google font
 */
function wpbforwpbakerypro_enqueue_google_font( $font_data ){
	$settings = get_option( 'wpb_js_google_fonts_subsets' );
	if ( is_array( $settings ) && ! empty( $settings ) ) {
		$subsets = '&subset=' . implode( ',', $settings );
	} else {
		$subsets = '';
	}
	
	if ( isset( $font_data['values']['font_family'] ) ) {
		wp_enqueue_style('vc_google_fonts_' . vc_build_safe_css_class( $font_data['values']['font_family'] ), '//fonts.googleapis.com/css?family=' . $font_data['values']['font_family'] . $subsets );
	}
}

/*
 * wpbakery row custom class
 * return css class
 */
function wpbforwpbakerypro_get_vc_custom_class( $param_value, $prefix = '', $atts = '' ){
	if(function_exists('vc_shortcode_custom_css_class')){ 
		return vc_shortcode_custom_css_class($param_value, $prefix);
	}
	$css_class = preg_match( '/\s*\.([^\{]+)\s*\{\s*([^\}]+)\s*\}\s*/', $param_value ) ? $prefix . preg_replace( '/\s*\.([^\{]+)\s*\{\s*([^\}]+)\s*\}\s*/', '$1', $param_value ) : '';

	return $css_class;
}

/**
* Usages: "wpbforwpbakerypro_add_to_wishlist_button()" function is used  to modify the wishlist button from "YITH WooCommerce Wishlist" plugins.
* Plugins URL: https://wordpress.org/plugins/yith-woocommerce-wishlist/
* File Path: yith-woocommerce-wishlist/templates/add-to-wishlist.php
* The below Function depends on YITH WooCommerce Wishlist plugins. If YITH WooCommerce Wishlist is installed and actived, then it will work.
*/
function wpbforwpbakerypro_add_to_wishlist_button( $normalicon = '<i class="fa fa-heart-o"></i>', $addedicon = '<i class="fa fa-heart"></i>', $tooltip = 'no' ) {
    global $product;

    $product_id = $product->get_id();

    $output = '';

    if( class_exists('WishSuite_Base') ){

        $button_text        = wishsuite_get_option( 'button_text','wishsuite_settings_tabs', 'Wishlist' );
        $button_added_text  = wishsuite_get_option( 'added_button_text','wishsuite_settings_tabs', 'Product Added' );
        $button_exist_text  = wishsuite_get_option( 'exist_button_text','wishsuite_settings_tabs', 'Product already added' );
        
        $button_text = $normalicon.'<span class="wishsuite-btn-text">'.$button_text.'</span>';
        $button_added_text = $addedicon.'<span class="wishsuite-btn-text">'.$button_added_text.'</span>';
        $button_exist_text = $addedicon.'<span class="wishsuite-btn-text">'.$button_exist_text.'</span>';
        
        $button_class = 'wishsuite-btn wishsuite-button wishlist'.( $tooltip == 'yes' ? '' : ' wltooltip_no' );

        $button_args = [
            'btn_class' => $button_class,
            'btn_text' => $button_text,
            'btn_added_text' => $button_added_text,
            'btn_exist_text' => $button_exist_text,
        ];
        
        add_filter( 'wishsuite_button_arg', function( $button_arg ) use ( $button_args ) {

            $button_arg['button_class'] = $button_args['btn_class'];

            return $button_arg;
        }, 90, 1 );

        $output .= do_shortcode('[wishsuite_button]');
        return $output;

    }elseif( class_exists('TInvWL_Public_AddToWishlist') ){
        ob_start();
        TInvWL_Public_AddToWishlist::instance()->htmloutput();
        $output .= ob_get_clean();
        return $output;

    }elseif( class_exists( 'YITH_WCWL' ) || !empty( get_option( 'yith_wcwl_wishlist_page_id' ) ) ){
        global $yith_wcwl;
        $url          = YITH_WCWL()->get_wishlist_url();
        $product_type = $product->get_type();
        $exists       = $yith_wcwl->is_product_in_wishlist( $product->get_id() );
        $classes      = 'class="add_to_wishlist"';
        $add          = get_option( 'yith_wcwl_add_to_wishlist_text' );
        $browse       = get_option( 'yith_wcwl_browse_wishlist_text' );
        $added        = get_option( 'yith_wcwl_product_added_text' );

        $output  .= '<div class="'.( $tooltip == 'yes' ? '' : 'tooltip_no' ).' wishlist button-default yith-wcwl-add-to-wishlist add-to-wishlist-' . esc_attr( $product->get_id() ) . '">';
            $output .= '<div class="yith-wcwl-add-button';
                $output .= $exists ? ' hide" style="display:none;"' : ' show"';
                $output .= '><a href="' . esc_url( htmlspecialchars( YITH_WCWL()->get_wishlist_url() ) ) . '" data-product-id="' . esc_attr( $product->get_id() ) . '" data-product-type="' . esc_attr( $product_type ) . '" ' . $classes . ' >'.$normalicon.'<span class="ht-product-action-tooltip">'.esc_html( $add ).'</span></a>';
                $output .= '<i class="fa fa-spinner fa-pulse ajax-loading" style="visibility:hidden"></i>';
            $output .= '</div>';

            $output .= '<div class="yith-wcwl-wishlistaddedbrowse hide" style="display:none;"><a class="" href="' . esc_url( $url ) . '">'.$addedicon.'<span class="ht-product-action-tooltip">'.esc_html( $browse ).'</span></a></div>';
            $output .= '<div class="yith-wcwl-wishlistexistsbrowse ' . ( $exists ? 'show' : 'hide' ) . '" style="display:' . ( $exists ? 'block' : 'none' ) . '"><a href="' . esc_url( $url ) . '" class="">'.$addedicon.'<span class="ht-product-action-tooltip">'.esc_html( $added ).'</span></a></div>';
        $output .= '</div>';

        return $output;

    }else{
        return 0;
    }
}

// Check plugin is Installed or not
function wpbforwpbakerypro_is_plugins_installed( $pl_file_path = NULL ){
    $installed_plugins_list = get_plugins();
    return isset( $installed_plugins_list[$pl_file_path] );
}

// Check plugin is active or not
function wpbforwpbakerypro_is_plugins_active( $pl_file_path = NULL ){
    $active_plugins_list = get_option('active_plugins');
    return in_array( $pl_file_path, $active_plugins_list );
}


/**
 * Check if VC installed or not.
 * Few themes modify the js_composer plugin & supply it with the plugins, this is why this function introduced for
 * Must be loaded after, plugins loaded hook
 *
 * @since 2.0.0
 */
function wpbforwpbakerypro_find_vc_installed(){
    $plugin_file = '';

    if( function_exists('get_plugins') ){
        $plugins_list      = array_keys(get_plugins());

        foreach($plugins_list as $plugin){
            $pos = strpos($plugin, 'js_composer');
            if(gettype($pos) === 'integer'){
                $plugin_file = $plugin;
                break;
            }
        }
    }

    return $plugin_file;
}